@@ -87,7 +87,7 @@ fr_command_jar_add (FrCommand     *comm,
 		g_free (path);
 	}
 
-	tmp_dir = get_temp_work_dir ();
+	tmp_dir = get_temp_work_dir (NULL);
 	for (scan = jardata_list; scan ; scan = scan->next) {
 		JarData *jdata = scan->data;
 		char    *pack_path;
@@ -159,18 +159,27 @@ fr_command_jar_get_mime_types (FrCommand *comm)
 
 FrCommandCap
 fr_command_jar_get_capabilities (FrCommand  *comm,
-			         const char *mime_type)
+			         const char *mime_type,
+				 gboolean    check_command)
 {
 	FrCommandCap capabilities;
 
 	capabilities = FR_COMMAND_CAN_ARCHIVE_MANY_FILES;
-	if (is_program_in_path ("zip"))
+	if (is_program_available ("zip", check_command))
 		capabilities |= FR_COMMAND_CAN_READ_WRITE;
 
 	return capabilities;
 }
 
 
+static const char *
+fr_command_jar_get_packages (FrCommand  *comm,
+			     const char *mime_type)
+{
+	return "zip,unzip";
+}
+
+
 static void
 fr_command_jar_class_init (FrCommandJarClass *class)
 {
@@ -184,6 +193,7 @@ fr_command_jar_class_init (FrCommandJarClass *class)
 	afc->add = fr_command_jar_add;
 	afc->get_mime_types = fr_command_jar_get_mime_types;
 	afc->get_capabilities = fr_command_jar_get_capabilities;
+	afc->get_packages     = fr_command_jar_get_packages;
 }
 
 
